@@ -409,7 +409,7 @@ class FormStyleFactory:
                         field_value = field.f(vars)
                     else:
                         field_value = (
-                            field.represent and field.represent(value) or value or ""
+                            field.represent and field.represent(value, vars) or value or ""
                         )
                     field_type = "represent"
                     control = DIV(field_value)
@@ -880,7 +880,7 @@ class Form(object):
         payload = {"ts": str(time.time())}
         if self.lifespan is not None:
             payload["exp"] = time.time() + self.lifespan
-        key = self._make_key()
+        key = self._get_key() or self._make_key()
         self.formkey = to_native(jwt.encode(payload, key, algorithm="HS256"))
 
     def _verify_form(self, post_vars):
