@@ -50,6 +50,15 @@ def safe_int(text, default):
         return default
 
 
+def join_styles(items):
+    return "".join(items) if isinstance(items, (list, tuple)) else " %s" % items
+
+
+def clean_sc(**kwargs):
+    """returns a clean dict with _class and _style only if value"""
+    return {key: value for key, value in kwargs.items() if value}
+
+
 class GridClassStyle:
 
     """
@@ -100,6 +109,8 @@ class GridClassStyle:
         "grid-search-form-table": "grid-search-form-table",
         "grid-search-form-tr": "grid-search-form-tr",
         "grid-search-form-td": "grid-search-form-td",
+        "grid-search-form-input": "grid-search-form-input",
+        "grid-search-form-select": "grid-search-form-select",
         "grid-search-boolean": "grid-search-boolean",
         "grid-header-element": "grid-header-element info",
         "grid-footer-element": "grid-footer-element info",
@@ -146,6 +157,8 @@ class GridClassStyle:
         "grid-search-form-table": "",
         "grid-search-form-tr": "border-bottom: none;",
         "grid-search-form-td": "",
+        "grid-search-form-input": "",
+        "grid-search-form-select": "",
         "grid-search-boolean": "",
         "grid-header-element": "margin-top:4px; height:34px; line-height:34px;",
         "grid-footer-element": "margin-top:4px; height:34px; line-height:34px;",
@@ -154,10 +167,10 @@ class GridClassStyle:
     @classmethod
     def get(cls, element):
         """returns a dict with _class and _style for the element name"""
-        return {
-            "_class": cls.classes.get(element),
-            "_style": cls.styles.get(element),
-        }
+        return clean_sc(
+            _class=cls.classes.get(element),
+            _style=cls.styles.get(element),
+        )
 
 
 class GridClassStyleBulma(GridClassStyle):
@@ -205,6 +218,8 @@ class GridClassStyleBulma(GridClassStyle):
         "grid-search-form-table": "grid-search-form-table",
         "grid-search-form-tr": "grid-search-form-tr",
         "grid-search-form-td": "grid-search-form-td pr-1",
+        "grid-search-form-input": "grid-search-form-input input",
+        "grid-search-form-select": "grid-search-form-input control select",
         "grid-search-boolean": "grid-search-boolean",
         "grid-header-element": "grid-header-element button",
         "grid-footer-element": "grid-footer-element button",
@@ -252,6 +267,8 @@ class GridClassStyleBulma(GridClassStyle):
         "grid-search-form-table": "",
         "grid-search-form-tr": "",
         "grid-search-form-td": "",
+        "grid-search-form-input": "",
+        "grid-search-form-select": "",
         "grid-search-boolean": "padding-top: .5rem;",
         "grid-header-element": "",
         "grid-footer-element": "",
@@ -789,9 +806,6 @@ class Grid:
         classes = self.param.grid_class_style.classes.get(name, "")
         styles = self.param.grid_class_style.styles.get(name, "")
 
-        def join_style(items):
-            return "".join(items) if isinstance(items, (list, tuple)) else " %s" % items
-
         if callable(additional_classes):
             additional_classes = additional_classes(row)
 
@@ -809,9 +823,9 @@ class Grid:
         elif additional_classes:
             classes = join_classes(classes, additional_classes)
         if override_styles:
-            styles = join_style(override_styles)
+            styles = join_styles(override_styles)
         elif additional_styles:
-            styles += join_style(additional_styles)
+            styles += join_styles(additional_styles)
 
         if callable(url):
             url = url(row)
@@ -824,10 +838,9 @@ class Grid:
         link = A(
             I(_class="fa %s" % icon),
             _role="button",
-            _class=classes,
             _message=message,
             _title=button_text,
-            _style=styles,
+            **clean_sc(_class=classes, _style=styles),
             **attrs,
         )
         if self.param.include_action_button_text:
@@ -851,16 +864,20 @@ class Grid:
         ]
         attrs = self.attributes_plugin.link(url=self.endpoint)
         form = FORM(*hidden_fields, **attrs)
+        sc = self.param.grid_class_style.get("grid-search-form-select")
         select = SELECT(
             *options,
             **dict(
                 _name="search_type",
             ),
+            **sc,
         )
+        sc = self.param.grid_class_style.get("grid-search-form-input")
         input = INPUT(
             _type="text",
             _name="search_string",
             _value=search_string,
+            **sc,
         )
         sc = self.param.grid_class_style.get("grid-search-button")
         submit = INPUT(_type="submit", _value=self.T("Search"), **sc)
@@ -939,7 +956,7 @@ class Grid:
     def _make_table_header(self):
         sort_order = request.query.get("orderby", "")
 
-        thead = THEAD(_class=self.param.grid_class_style.classes.get("grid-thead", ""))
+        thead = THEAD(**clean_sc(_class=self.param.grid_class_style.classes.get("grid-thead", "")))
         for index, column in enumerate(self.param.columns):
             col = None
             if isinstance(column, (Field, FieldVirtual)):
@@ -959,7 +976,7 @@ class Grid:
                     "grid-col-%s" % key,
                 )
                 style = self.param.grid_class_style.styles.get("grid-th")
-                thead.append(TH(col, _class=classes, _style=style))
+                thead.append(TH(col, **clean_sc(_class=classes, _style=style)))
 
         return thead
 
@@ -1016,13 +1033,13 @@ class Grid:
                 field_value = field.f(row)
         elif self.use_tablename:
             field_value = (
-                field.represent(row[field.tablename][field.name])
+                field.represent(row[field.tablename][field.name], row[field.tablename])
                 if field.represent
                 else row[field.tablename][field.name]
             )
         else:
             field_value = (
-                field.represent(row[field.name]) if field.represent else row[field.name]
+                field.represent(row[field.name], row) if field.represent else row[field.name]
             )
         key = "%s.%s" % (field.tablename, field.name)
         formatter = (
@@ -1042,10 +1059,12 @@ class Grid:
             formatter(field_value)
             if formatter.__code__.co_argcount == 1  # if formatter has only 1 argument
             else formatter(field_value, row),
-            _class=classes,
-            _style=(
-                self.param.grid_class_style.styles.get(class_type)
-                or self.param.grid_class_style.styles.get("grid-td")
+            **clean_sc(
+                _class=classes,
+                _style=(
+                        self.param.grid_class_style.styles.get(class_type)
+                        or self.param.grid_class_style.styles.get("grid-td")
+                )
             ),
         )
 
@@ -1070,12 +1089,10 @@ class Grid:
                 extra_style = ""
             tr = TR(
                 _role="row",
-                _class=join_classes(
-                    self.param.grid_class_style.classes.get("grid-tr"), extra_class
-                ),
-                _style=join_classes(
-                    self.param.grid_class_style.styles.get("grid-tr"), extra_style
-                ),
+                **clean_sc(
+                    _class=join_classes(self.param.grid_class_style.classes.get("grid-tr"), extra_class),
+                    _style=join_styles([self.param.grid_class_style.styles.get("grid-tr"), extra_style]),
+                )
             )
             #  add all the fields to the row
             for index, column in enumerate(self.param.columns):
@@ -1093,7 +1110,7 @@ class Grid:
                         self.param.grid_class_style.styles.get("grid-td"),
                     )
                     tr.append(
-                        TD(column.render(row, index), _class=classes, _style=style)
+                        TD(column.render(row, index), **clean_sc(_class=classes, _style=style))
                     )
 
             td = None
